@@ -1,17 +1,17 @@
 PROFILE_FUNC_LIST = []
 from mypy import cookie
 
-import hotshot,hotshot.stats
+import hotshot, hotshot.stats
 from os import getpid
 from cStringIO import StringIO
 import os
 import re
 import time
-from os.path import abspath,dirname,join
-from tempfile import gettempdir 
-tempdir=gettempdir()
-PROFILE_LOG_FILENAME_PATTERN = join(tempdir,'profile-%s.prof')
-PROFILE_PICKLE_FILENAME_PATTERN = join(tempdir,'profile-%s.pickle')
+from os.path import abspath, dirname, join
+from tempfile import gettempdir
+tempdir = gettempdir()
+PROFILE_LOG_FILENAME_PATTERN = join(tempdir, 'profile-%s.prof')
+PROFILE_PICKLE_FILENAME_PATTERN = join(tempdir, 'profile-%s.pickle')
 PROFILE_LIMIT = 60
 
 class ProfileInfo:
@@ -92,7 +92,7 @@ def format_stats(stats, strip_dirs=None, sort='time'):
         rootdir = dirname(
             dirname(dirname(dirname(abspath(__file__))))
         ).lower()+os.sep
-        r = r.replace(rootdir,"")
+        r = r.replace(rootdir, "")
     return r
 
 normalize_re = re.compile(r'\d+')
@@ -119,17 +119,17 @@ def format_call(funcname, *a, **kw):
     arglist = []
     for v in a:
         v = repr(v)
-        if len(v)>70:
-            v=v[:70]+"..."
+        if len(v) > 70:
+            v = v[:70]+"..."
         arglist.append(v)
 
     r = []
     for k, v in kw.iteritems():
-        if len(v)>70:
-            v=v[:70]+"..."
-        r.append((k,v))
-        
-    arglist += ["%s=%r" % (k,v) for k,v in r]
+        if len(v) > 70:
+            v = v[:70]+"..."
+        r.append((k, v))
+
+    arglist += ["%s=%r" % (k, v) for k, v in r]
     return "%s(%s)" % (funcname, ", ".join(arglist))
 
 def ProfileMiddleware(application):
@@ -137,11 +137,11 @@ def ProfileMiddleware(application):
         profile = request.query.profile
         cookie_profile = request.cookie.get("profile")
         if profile or cookie_profile:
-            if profile=="0":
-                cookie.delete("profile",request=request)
+            if profile == "0":
+                cookie.delete("profile", request=request)
             else:
                 if not cookie_profile:
-                    cookie.set("profile","1",request=request)
+                    cookie.set("profile", "1", request=request)
                 #from zku.autumn.model import sqlstore
                 prof = start_profile()
                 for i in PROFILE_FUNC_LIST:
@@ -151,7 +151,7 @@ def ProfileMiddleware(application):
                 so = []
                 result = None
                 try:
-                    result = prof.runcall(application,request)
+                    result = prof.runcall(application, request)
                     for i in PROFILE_FUNC_LIST:
                         so.append(i.get_log())
                 #    so += sqlstore.get_log()
@@ -159,22 +159,22 @@ def ProfileMiddleware(application):
                 finally:
                     for i in PROFILE_FUNC_LIST:
                         i.stop_log()
-                #    mc.stop_log()
-                #    sqlstore.stop_log()
+                    #    mc.stop_log()
+                    #    sqlstore.stop_log()
                     prof.close()
 
-                if result is not None and (result.startswith("<") or profile):
+                if result is not None and (result.lstrip().startswith("<") or profile):
                     #disable output for json
                     stats = load_stats()
-                    
+
                     so.append( format_stats(stats, sort='time') )
                     so.append( format_stats(stats, sort='cumulative') )
-                    
+
                     from cgi import escape
                     splitor = "\n"+"=*"*60+"\n\n\n"
                     so = escape(splitor.join(so))
                     so = """<pre style="clear:both;padding:1em;background:#ffffde;color:#033">\n%s\n</pre>"""%so
-                    result = "%s %s"%(result,so)
+                    result = "%s %s"%(result, so)
                 return result
         return application(request)
     return _application
