@@ -1,25 +1,6 @@
 #!/usr/bin/env python
-#
-# Copyright 2009 Facebook
-#
-# Licensed under the Apache License, Version 2.0 (the "License"); you may
-# not use this file except in compliance with the License. You may obtain
-# a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
-# License for the specific language governing permissions and limitations
-# under the License.
 
-"""The Tornado web framework ."""
-
-try:
-    import cStringIO as StringIO
-except:
-    import StringIO
+import cStringIO as StringIO
 import sys
 import urllib
 import calendar
@@ -42,6 +23,7 @@ class WSGIHandler(object):
         self._finished = False
         self._auto_finish = True
         self._wsgi_headers = ()
+        self._transforms = ()
         self.clear()
 
     def delegate(self):
@@ -164,17 +146,21 @@ class WSGIHandler(object):
         else:
             headers = ""
 
-        # Ignore the chunk and only write the headers for HEAD requests
-        if self.request.method == "HEAD":
-            if headers: self.request.write(headers)
-            return
-
         if self._write_buffer:
             chunk = "".join(self._write_buffer)
             self._write_buffer = []
+            if chunk:
+                for transform in self._transforms:
+                    chunk = transform.transform_chunk(chunk)
         else:
             chunk = ""
 
+        if include_footers:
+            footers = []
+            for transform in self._transforms:
+                footer = transform.footer()
+                if footer: chunk += footer
+
         if headers or chunk:
             self.request.write(headers + chunk)
 
@@ -254,7 +240,8 @@ class WSGIHandler(object):
         return wrapper
 
 
-    def _execute(self, *args, **kwargs):
+    def _execute(self, transforms, *args, **kwargs):
+        self._transforms = transforms
         try:
             self.prepare()
             if not self._finished:
@@ -265,6 +252,8 @@ class WSGIHandler(object):
             self._handle_request_exception(e)
 
     def _generate_headers(self):
+        for transform in self._transforms:
+            headers = transform.transform_headers(self._headers)
         headers = self._headers
         lines = [self.request.version + " " + str(self._status_code) + " " +
                  httplib.responses[self._status_code]]
@@ -333,29 +322,41 @@ def asynchronous(method):
 
 
 class Application(object):
-    """A collection of request handlers that make up a web application.
-
-    Instances of this class are callable and can be passed directly to
-    HTTPServer to serve the application:
-
-        application = web.Application([
-            (r"/", MainPageHandler),
-        ])
-        http_server = httpserver.HTTPServer(application)
-        http_server.listen(8080)
-        ioloop.IOLoop.instance().start()
-
-    """
-    def __init__(self, handler):
+    def __init__(self, handler, transforms):
         self.handlers = []
         self.handler = handler
+        self.transforms = transforms
 
 
     def __call__(self, request):
-        """Called by HTTPServer to execute the request."""
         handler_class, app = self.handler
         handler = handler_class(self, request, app)
-        handler._execute()
+        handler._execute(self.transforms)
         return handler
 
 
+class ChunkedTransferEncoding(object):
+    def __init__(self, request):
+        self._chunking = request.supports_http_1_1()
+
+    def transform_headers(self, headers):
+        print "!!!transform"
+        if self._chunking:
+            # No need to chunk the output if a Content-Length is specified
+            if "Content-Length" in headers or "Transfer-Encoding" in headers:
+                self._chunking = False
+            else:
+                headers["Transfer-Encoding"] = "chunked"
+        return headers
+
+    def transform_chunk(self, block):
+        if self._chunking:
+            return ("%x" % len(block)) + "\r\n" + block + "\r\n"
+        else:
+            return block
+
+    def footer(self):
+        if self._chunking:
+            return "0\r\n\r\n"
+        else:
+            return None
\ No newline at end of file
