@@ -4,13 +4,14 @@
 import web
 import httpserver
 import ioloop
-from web import WSGIHandler
+from web import WSGIHandler, ChunkedTransferEncoding
 
 class WSGIServer(httpserver.HTTPServer):
     """HTTP Server to work with wsgi applications."""
-    def __init__(self, port, wsgi_app):
+    def __init__(self, port, wsgi_app , transforms=(ChunkedTransferEncoding, )):
         application = web.Application(
-            (WSGIHandler, wsgi_app)
+            (WSGIHandler, wsgi_app),
+            transforms
         )
         httpserver.HTTPServer.__init__(self, application)
         self.listen(port)
@@ -19,7 +20,6 @@ class WSGIServer(httpserver.HTTPServer):
         ioloop.IOLoop.instance().start()
 
 
-
 class SocketLocalMiddleware:
     """WSGI middleware to setup socket-local for request handling socket-thread."""
     def __init__(self, wsgi_app):
